| beidsServer | R Documentation |
Shiny module for searching BEIDs
beidsServer(
id,
toGene = TRUE,
excludeTechID = FALSE,
multiple = FALSE,
beOfInt = NULL,
selectBe = TRUE,
orgOfInt = NULL,
selectOrg = TRUE,
groupBySymbol = FALSE,
searchLabel = "Search a gene",
matchColname = "Match",
selectFirst = FALSE,
oneColumn = FALSE,
withId = FALSE,
maxHits = 75,
clean_id_search = TRUE,
clean_name_search = TRUE,
fuzzy = TRUE,
compact = FALSE,
tableHeight = 150,
highlightStyle = "",
highlightClass = "bed-search",
inputUpdateOn = c("change", "blur")
)
beidsUI(id)
id |
an identifier for the module instance |
toGene |
focus on gene entities (default=TRUE): matches from other BE are converted to genes. |
excludeTechID |
do not display BED technical BEIDs |
multiple |
allow multiple selections (default=FALSE) |
beOfInt |
if toGene == FALSE, BE to consider (default=NULL ==> all) |
selectBe |
if toGene == FALSE, display an interface for selecting BE |
orgOfInt |
organism to consider (default=NULL ==> all) |
selectOrg |
display an interface for selecting organisms |
groupBySymbol |
if TRUE also use gene symbols to aggregate results with more granularity (taken into account only when toGene == TRUE) |
searchLabel |
display label for the search field or NULL for no label |
matchColname |
display name of the match column |
selectFirst |
if TRUE the first row is selected by default |
oneColumn |
if TRUE the hits are displayed in only one column |
withId |
if FALSE and one column, the BEIDs are not shown |
maxHits |
maximum number of raw hits to return |
clean_id_search |
clean x to avoid error during ID search. Default: TRUE. Set it to false if you're sure of your lucene query. |
clean_name_search |
clean x to avoid error during ID search. Default: TRUE. Set it to false if you're sure of your lucene query. |
fuzzy |
if TRUE (default) a fuzzy search is applied on names and symbols. |
compact |
compact display (default: FALSE) |
tableHeight |
height of the result table (default: 150) |
highlightStyle |
style to apply to the text to highlight |
highlightClass |
class to apply to the text to highlight |
inputUpdateOn |
A character vector specifying when the input should be updated. Options are "change" (default) and "blur". Use "change" to update the input immediately whenever the value changes. Use "blur"to delay the input update until the input loses focus (the user moves away from the input), or when Enter is pressed. |
A reactive data.frame with the following columns:
beid: the BE identifier
preferred: preferred identifier for the same BE in the same scope
be: the type of biological entity
source: the source of the identifier
organism: the BE organism
entity: internal identifier of the BE
match: the matching character string
beidsUI(): UI part of the BED identifiers shiny module
## Not run:
library(shiny)
library(BED)
library(DT)
ui <- fluidPage(
beidsUI("be"),
fluidRow(
column(
12,
tags$br(),
h3("Selected gene entities"),
DTOutput("result")
)
)
)
server <- function(input, output){
found <- beidsServer("be", toGene=TRUE, multiple=TRUE, tableHeight=250)
output$result <- renderDT({
req(found())
toRet <- found()
datatable(toRet, rownames=FALSE)
})
}
shinyApp(ui = ui, server = server)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.